==> cutetube_1.7.1.tar.gz: cutetube-1.7.1/cutetubeapp/src/base/archivelistmodel.h <==
#ifndef ARCHIVELISTMODEL_H
#define ARCHIVELISTMODEL_H

#include "videoitem.h"
#include <QSortFilterProxyModel>
#include <QSharedPointer>

class Session;
class QFileSystemModel;

class ArchiveListModel : public QSortFilterProxyModel
{
    Q_OBJECT

    Q_PROPERTY(Session* session
               READ session
               WRITE setSession)
    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)
    Q_PROPERTY(QString query
               READ query
               WRITE setQuery
               NOTIFY queryChanged)
    Q_PROPERTY(QModelIndex rootIndex
               READ rootIndex
               CONSTANT)
    Q_PROPERTY(QString highlightColor
               READ highlightColor
               WRITE setHighlightColor)

public:
    enum Roles {
        FilePathRole = Qt::UserRole + 1,
        TitleRole,
        TitleMatchRole,
        DateRole,
        DateStringRole,
        ThumbnailPathRole,
        UrlRole
    };

public:
    explicit ArchiveListModel(Session *session = 0, QObject *parent = 0);
    inline Session* session() const { return m_session; }
    void setSession(Session *session);
    QString regexMatch(QString str) const;
    inline QString query() const { return m_query; }
    QVariant data(const QModelIndex &index, int role) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
    QSharedPointer<VideoItem> get(const QModelIndex &index) const;
    Q_INVOKABLE VideoItem* getFromQML(int row) const;
    QModelIndex rootIndex() const;
    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const;
    inline QString highlightColor() const { return m_highlight; }
    inline void setHighlightColor(const QString &color) { m_highlight = color; }

public slots:
    void setQuery(const QString &query);
    void deleteVideo(const QModelIndex &index);

signals:
    void alert(const QString &message);
    void error(const QString &message);
    void directoryLoaded(const QString &path);
    void countChanged(int count);
    void queryChanged(const QString &query);

private:
    Session *m_session;
    QFileSystemModel *m_model;
    QString m_query;
    QString m_highlight;
};

#endif // ARCHIVELISTMODEL_H

==> cutetube_1.8.0.tar.gz: cutetube-1.8.0/cutetubeapp/src/base/archivelistmodel.h <==
#ifndef ARCHIVELISTMODEL_H
#define ARCHIVELISTMODEL_H

#include "videoitem.h"
#include <QSortFilterProxyModel>
#include <QSharedPointer>

class QFileSystemModel;

class ArchiveListModel : public QSortFilterProxyModel
{
    Q_OBJECT

    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)
    Q_PROPERTY(QString query
               READ query
               WRITE setQuery
               NOTIFY queryChanged)
    Q_PROPERTY(QModelIndex rootIndex
               READ rootIndex
               CONSTANT)
    Q_PROPERTY(QString highlightColor
               READ highlightColor
               WRITE setHighlightColor)

public:
    enum Roles {
        FilePathRole = Qt::UserRole + 1,
        TitleRole,
        TitleMatchRole,
        DateRole,
        DateStringRole,
        ThumbnailPathRole,
        UrlRole
    };

public:
    explicit ArchiveListModel(QObject *parent = 0);
    QString regexMatch(QString str) const;
    inline QString query() const { return m_query; }
    QVariant data(const QModelIndex &index, int role) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
    QSharedPointer<VideoItem> get(const QModelIndex &index) const;
#ifdef QML_USER_INTERFACE
    Q_INVOKABLE VideoItem* getFromQML(int row) const;
#endif
    QModelIndex rootIndex() const;
    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const;
    inline QString highlightColor() const { return m_highlight; }
    inline void setHighlightColor(const QString &color) { m_highlight = color; }

public slots:
    void setQuery(const QString &query);
    void deleteVideo(const QModelIndex &index);

signals:
    void alert(const QString &message);
    void error(const QString &message);
    void directoryLoaded(const QString &path);
    void countChanged(int count);
    void queryChanged(const QString &query);

private:
    QFileSystemModel *m_model;
    QString m_query;
    QString m_highlight;
};

#endif // ARCHIVELISTMODEL_H
